summaryrefslogtreecommitdiff
path: root/src/lib/job.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/job.cc')
-rw-r--r--src/lib/job.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/job.cc b/src/lib/job.cc
index d4023973c..95f09a4dc 100644
--- a/src/lib/job.cc
+++ b/src/lib/job.cc
@@ -63,13 +63,13 @@ Job::Job (shared_ptr<const Film> film)
Job::~Job ()
{
#ifdef DCPOMATIC_DEBUG
/* Any subclass should have called destroy_thread in its destructor */
assert (!_thread);
#endif
}
void
-Job::destroy_thread ()
+Job::stop_thread ()
{
if (_thread) {
_thread->interrupt ();
@@ -63,13 +63,13 @@ Job::Job (shared_ptr<const Film> film)
{
#ifdef DCPOMATIC_DEBUG
- /* Any subclass should have called destroy_thread in its destructor */
+ /* Any subclass should have called stop_thread in its destructor */
assert (!_thread);
#endif